@@ -3,13 +3,15 @@ Main interface for datapipeline service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.datapipeline import DataPipelineClient
+    from mypy_boto3_datapipeline import DataPipelineClient
 
     session = boto3.Session()
 
     client: DataPipelineClient = boto3.client("datapipeline")
     session_client: DataPipelineClient = session.client("datapipeline")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
