@@ -3,8 +3,11 @@ Main interface for datapipeline service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.datapipeline import (
+
+    from mypy_boto3_datapipeline import DataPipelineClient
+    from mypy_boto3_datapipeline import (
         DescribeObjectsPaginator,
         ListPipelinesPaginator,
         QueryObjectsPaginator,
@@ -15,6 +18,7 @@ Usage::
     describe_objects_paginator: DescribeObjectsPaginator = client.get_paginator("describe_objects")
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     query_objects_paginator: QueryObjectsPaginator = client.get_paginator("query_objects")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, List, TYPE_CHECKING
